@@ -90,9 +90,15 @@ class LoggingMixin(object):
         pass
 
     def call(self, method, asset_id, text):
-        if str(method) in self.LOGGING_LEVELS[0:self.LOGGING_LEVELS.index(self.logging_level) + 1] \
-                and asset_id == self.logging_asset_id:
-            self.log(asset_id, text)
+        method_check = str(method) in self.LOGGING_LEVELS[0:self.LOGGING_LEVELS.index(self.logging_level) + 1]
+        if not method_check:
+            return
+
+        asset_id_check = (asset_id == self.logging_asset_id) or (self.logging_asset_id == 'all')
+        if not asset_id_check:
+            return
+
+        self.log(asset_id, text)
 
     @staticmethod
     def log(asset_id, text):
